@@ -39,7 +39,7 @@ use warnings;
 use utf8;
 use 5.008008; # minumum perl version is 5.8.8
 
-our $VERSION = "0.963_3";
+our $VERSION = "0.972_1";
 our $VERSION_MATURITY = "beta";
 
 use constant ONE_MB => 1024*1024;
@@ -118,7 +118,7 @@ sub process
 		die "Not a directory $options->{dir}" unless -d binaryfilename $options->{dir};
 
 		my $j = App::MtAws::Journal->new(%journal_opts, journal_file => $options->{journal}, root_dir => $options->{dir},
-			filter => $options->{filters}{parsed}, leaf_optimization => $options->{'leaf-optimization'});
+			filter => $options->{filters}{parsed}, leaf_optimization => $options->{'leaf-optimization'}, follow => $options->{'follow'});
 
 		require App::MtAws::SyncCommand;
 		App::MtAws::SyncCommand::run($options, $j);
@@ -280,22 +280,25 @@ Common options:
 	--timeout - socket timeout
 Commands:
 	sync
-		--leaf-optimization - Don't use directory hardlinks count when traverse.
+	  --new --replace-modified --delete-removed - Sync modes
+	  --leaf-optimization - Don't use directory hardlinks count when traverse.
+	  --follow - Follow symbolic links
+	  --detect treehash|mtime|mtime-or-treehash|mtime-and-treehash|always-positive|size-only
 	purge-vault
 	restore
 	restore-completed
-		--segment-size - Size for multi-segment download, in megabytes
+	  --segment-size - Size for multi-segment download, in megabytes
 	check-local-hash
 	retrieve-inventory
 	download-inventory
-		--new-journal - Write inventory as new journal
+	  --new-journal - Write inventory as new journal
 	create-vault VAULT-NAME
 	delete-vault VAULT-NAME
 	upload-file
-		--filename - File to upload
-		--set-rel-filename - Relative filename to use in Journal (if dir not specified)
-		--stdin - Upload from STDIN
-		--check-max-file-size - Specify to ensure there will be less than 10 000 parts
+	  --filename - File to upload
+	  --set-rel-filename - Relative filename to use in Journal (if dir not specified)
+	  --stdin - Upload from STDIN
+	  --check-max-file-size - Specify to ensure there will be less than 10 000 parts
 Config format (text file):
 	key=YOURKEY
 	secret=YOURSECRET
